#!/bin/bash
# Explore the effect of an increasing Monhorst-Pack grid and cutoff energy
# nguyen@flex.phys.tohoku.ac.jp
#############

name='gr.ecut'

#############
n=12; s=0;

for ecut in 10 15 20 25 30 35 40 45 50 60 70 80 100; do

cat > $name.$ecut.in << EOF
 &CONTROL
       calculation = 'scf',
      restart_mode = 'from_scratch',
        pseudo_dir = '../pseudo/',
            outdir = '../tmp/',
            prefix = 'gr',
 /
 &SYSTEM
             ibrav = 4,
                 a = 2.4623,
                 c = 10
               nat = 2,
              ntyp = 1,
       occupations = 'smearing',
          smearing = 'methfessel-paxton',
           degauss = 0.02,
           ecutwfc = ${ecut},
           ecutrho = 720,
              nbnd = 8,
 /
 &ELECTRONS
          conv_thr = 1.0d-8,
       mixing_beta = 0.7,
 /
ATOMIC_SPECIES
C 12.0107 C.pbe-rrkjus.UPF
ATOMIC_POSITIONS (crystal)
C  0.333333333  0.666666666  0.500000000
C  0.666666666  0.333333333  0.500000000
K_POINTS (automatic)
${n} ${n} ${n} ${s} ${s} ${s}
EOF

mpirun -np 2 pw.x <$name.$ecut.in>$name.$ecut.out

awk '/\!/ {E=$5} $1=="PWSCF" {printf"%4d %s %s\n",'$ecut',E,$3}' $name.$ecut.out >> calc-ecut.dat

done
